@@ -64,14 +64,16 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, collectio
 
     return return_list
 
+
 def two_way(operation, success=True, fail=False):
     import warnings
     warnings.filterwarnings("ignore")
     import re, keyword
     from collections import defaultdict
-    failed, succeeded = defaultdict(set) * 2
+    failed = defaultdict(set)
+    succeeded = defaultdict(set)
     invalid = 'Error|Warning|__|ipython|display|execfile|dreload|help|license|open|get_ipython|credits|runfile' \
-              '|copyright|breakpoint|input|print '
+              '|copyright|breakpoint|input|print'
     for a, i in keyword.__builtins__.items():
         if not re.search(invalid, a):
             for b, j in keyword.__builtins__.items():
